part of swagger.api;



class JobDetailsApi {
  final ApiClient apiClient;

  JobDetailsApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// /jobs/{id}
  ///
  /// Description: Obtain information of a specific job
  Future<Job> getJob(String id) async {
    Object postBody = null;

    // verify required params are set
    if(id == null) {
     throw new ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/jobs/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = [];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["ApiAuthKey"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return
          apiClient.deserialize(response.body, 'Job') as Job ;
    } else {
      return null;
    }
  }
  /// /jobs/{id}/notifications
  ///
  /// Description: To obtain a list of notifications to a specific job
  Future<Notifications> getJobNotifications(String id) async {
    Object postBody = null;

    // verify required params are set
    if(id == null) {
     throw new ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/jobs/{id}/notifications".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = [];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["ApiAuthKey"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return
          apiClient.deserialize(response.body, 'Notifications') as Notifications ;
    } else {
      return null;
    }
  }
  /// /jobs/{id}/preview
  ///
  /// Description: To obtain the preview pdf document of a specific job
  Future<Preview> getJobPreviews(String id) async {
    Object postBody = null;

    // verify required params are set
    if(id == null) {
     throw new ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/jobs/{id}/preview".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = [];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["ApiAuthKey"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return
          apiClient.deserialize(response.body, 'Preview') as Preview ;
    } else {
      return null;
    }
  }
  /// /jobs/{id}/recipients
  ///
  /// Description: Resource to obtain a list of recipients to a specific job
  Future<JobRecipients> getJobRecipients(String id, { int objectLimit, int objectOffset, String filterFaxNumber, String filterFaxNumberNorm, String filterRecipientReference, String filterInternationalDialingCode, String filterResultCode, String filterResultText, String sortField, String sortOrder }) async {
    Object postBody = null;

    // verify required params are set
    if(id == null) {
     throw new ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/jobs/{id}/recipients".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(objectLimit != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "objectLimit", objectLimit));
    }
    if(objectOffset != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "objectOffset", objectOffset));
    }
    if(filterFaxNumber != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "filterFaxNumber", filterFaxNumber));
    }
    if(filterFaxNumberNorm != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "filterFaxNumberNorm", filterFaxNumberNorm));
    }
    if(filterRecipientReference != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "filterRecipientReference", filterRecipientReference));
    }
    if(filterInternationalDialingCode != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "filterInternationalDialingCode", filterInternationalDialingCode));
    }
    if(filterResultCode != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "filterResultCode", filterResultCode));
    }
    if(filterResultText != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "filterResultText", filterResultText));
    }
    if(sortField != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sortField", sortField));
    }
    if(sortOrder != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "sortOrder", sortOrder));
    }
    
    List<String> contentTypes = [];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["ApiAuthKey"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return
          apiClient.deserialize(response.body, 'JobRecipients') as JobRecipients ;
    } else {
      return null;
    }
  }
  /// /jobs/{id}/templates
  ///
  /// Description: To obtain a list of template documents to a specific job
  Future<Templates> getJobTemplates(String id) async {
    Object postBody = null;

    // verify required params are set
    if(id == null) {
     throw new ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/jobs/{id}/templates".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = [];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["ApiAuthKey"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return
          apiClient.deserialize(response.body, 'Templates') as Templates ;
    } else {
      return null;
    }
  }
  /// /jobs/{id}
  ///
  /// Description: Control the transmission of the specific job
  Future<Job> putJob(JobsIdBody body, String id) async {
    Object postBody = body;

    // verify required params are set
    if(body == null) {
     throw new ApiException(400, "Missing required param: body");
    }
    if(id == null) {
     throw new ApiException(400, "Missing required param: id");
    }

    // create path and map variables
    String path = "/jobs/{id}".replaceAll("{format}","json").replaceAll("{" + "id" + "}", id.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["ApiAuthKey"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'PUT',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return
          apiClient.deserialize(response.body, 'Job') as Job ;
    } else {
      return null;
    }
  }
}
