part of swagger.api;

class JobOptions {
  /* Describes a title of a fax job */
  String title = null;
/* Describes the date the fax should be sent. The format complies with ISO 8601 and contains date and time */
  DateTime timeToSend = null;
/* Describes the date the fax can be sent until. The format complies with ISO 8601 and contains date and time */
  DateTime timeToSendUntil = null;
/* Describes if the fax header is used or not in a fax job */
  bool faxHeader = null;
/* Describes the header part from in the fax header (if its used) in a fax job */
  String faxHeaderFrom = null;
/* Describes the source identifier, which will be displayed during the transmission and appears on the receipt protocol */
  String stationID = null;
/* Describes the Calling Line Identification Presentation (Clip). It is the transferred dialing number before the transmission of the fax document */
  String clip = null;
/* Describes the default International Dialing Code which will be used for fax numbers without international area code */
  String defaultInternationalDialingCode = null;
/* Describes the used cost center for a fax job */
  String costCenter = null;
/* Describes if the uploaded template documents and resulting preview documents of a fax job are stored or not */
  bool saveDocuments = null;

  JobOptions();

  @override
  String toString() {
    return 'JobOptions[title=$title, timeToSend=$timeToSend, timeToSendUntil=$timeToSendUntil, faxHeader=$faxHeader, faxHeaderFrom=$faxHeaderFrom, stationID=$stationID, clip=$clip, defaultInternationalDialingCode=$defaultInternationalDialingCode, costCenter=$costCenter, saveDocuments=$saveDocuments, ]';
  }

  JobOptions.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    title = json['title'];
    timeToSend = json['timeToSend'] == null ? null : DateTime.parse(json['timeToSend']);
    timeToSendUntil = json['timeToSendUntil'] == null ? null : DateTime.parse(json['timeToSendUntil']);
    faxHeader = json['faxHeader'];
    faxHeaderFrom = json['faxHeaderFrom'];
    stationID = json['stationID'];
    clip = json['clip'];
    defaultInternationalDialingCode = json['defaultInternationalDialingCode'];
    costCenter = json['costCenter'];
    saveDocuments = json['saveDocuments'];
  }

  Map<String, dynamic> toJson() {
    return {
      'title': title,
      'timeToSend': timeToSend == null ? '' : timeToSend.toUtc().toIso8601String(),
      'timeToSendUntil': timeToSendUntil == null ? '' : timeToSendUntil.toUtc().toIso8601String(),
      'faxHeader': faxHeader,
      'faxHeaderFrom': faxHeaderFrom,
      'stationID': stationID,
      'clip': clip,
      'defaultInternationalDialingCode': defaultInternationalDialingCode,
      'costCenter': costCenter,
      'saveDocuments': saveDocuments
     };
  }

  static List<JobOptions> listFromJson(List<dynamic> json) {
    return json == null ? new List<JobOptions>() : json.map((value) => new JobOptions.fromJson(value)).toList();
  }

  static Map<String, JobOptions> mapFromJson(Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, JobOptions>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) => map[key] = new JobOptions.fromJson(value));
    }
    return map;
  }
}
